/*!
 * vue-coe-utils v0.0.1
 * (c) 2018-present Vinicius Azevedo <viniazvd@gmail.com>
 * Released under the MIT License.
 */
'use strict';

// https://repl.it/@viniazvd/isValid
var isValid = function (value) {
  if (Array.isArray(value)) { return !!value.length; }
  if (typeof value === 'object') { return !!Object.keys(value).length; }
  if (typeof value === 'string') { return !!value.length; }
  if (typeof value === 'number') { return !!value; }
  return !!value;
}; // https://repl.it/@viniazvd/getAbsolutValue


var getAbsolutValue = function (n) { return Math.pow( (n * n), 0.5 ); };

var isMobile = function () {
  return /(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|ipad|iris|kindle|Android|Silk|lge |maemo|midp|mmp|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp2|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i.test(navigator.userAgent);
}; // trick to remove object references


var clone = function (data) { return JSON.parse(JSON.stringify(data)); }; // https://repl.it/@viniazvd/containsWord


var containsWord = function (word, words) {
  if ( word === void 0 ) word = '';
  if ( words === void 0 ) words = '';

  return !!(words.toLowerCase().split(word.toLowerCase()).length - 1);
}; // https://repl.it/@viniazvd/removeDuplicates


var removeDuplicates = function (arr, prop) {
  var digest = arr.reduce(function (acc, el) {
    if (!acc.has(el[prop])) { acc.set(el[prop], el); }
    return acc;
  }, new Map());
  return [].concat( digest.values() );
}; // https://repl.it/@viniazvd/paginate


var pagination = function (array, paginate) {
  if ( array === void 0 ) array = [];
  if ( paginate === void 0 ) paginate = {};

  var current_page = paginate.current_page; if ( current_page === void 0 ) current_page = 0;
  var from = paginate.from; if ( from === void 0 ) from = 0;
  var per_page = paginate.per_page; if ( per_page === void 0 ) per_page = 10;
  var to = paginate.to; if ( to === void 0 ) to = 0;
  var total = paginate.total;
  var data = array.slice((current_page - 1) * per_page, per_page * current_page);
  from = (current_page - 1) * per_page + 1;
  to = (current_page - 1) * per_page + data.length;
  total = array.length;
  return {
    data: data,
    current_page: current_page,
    from: from,
    per_page: 10,
    to: to,
    total: total
  };
}; // https://repl.it/@viniazvd/compare-objects (ft. -@woods)


var equals = function (obj1, obj2) {
  if (!isValid(obj1) || !isValid(obj2)) { return false; }

  var isObject = function (data) { return typeof data === 'object'; };

  var hasOwnProperty = function (obj1, obj2, key) { return obj1.hasOwnProperty(key) === obj2.hasOwnProperty(key); };

  return Object.keys(obj1).every(function (key) {
    if (!hasOwnProperty(obj1, obj2, key)) { return false; }
    return isObject(obj1[key]) ? equals(obj1[key], obj2[key]) : obj1[key] === obj2[key];
  });
}; // https://repl.it/@viniazvd/translateEntity (ft. -@lubien)


var translateEntity = function (labels, entity) {
  return labels.map(function (ref) {
    var propName = ref[0];
    var mappedName = ref[1];

    return ({
    name: mappedName,
    value: entity[propName]
  });
  });
}; // https://repl.it/@viniazvd/isFormValid (ft. -@lubien)


var isFormValid = function (requireds, form) {
  if ( requireds === void 0 ) requireds = [];
  if ( form === void 0 ) form = {};

  var isValid = function (prop) { return form[prop]; };

  return requireds.every(isValid);
}; // https://repl.it/@viniazvd/final-formValidator (ft. -@lubien)


var formValidator = function (requireds, obj, x) {
  if ( x === void 0 ) x = new Set(requireds);

  return Object.entries(obj).reduce(function (acc, ref) {
  var key = ref[0];
  var value = ref[1];

  acc[key] = !!(x.has(key) && value);
  return acc;
}, {});
}; // https://repl.it/@viniazvd/formRequireds


var formRequireds = function (obj, requireds) {
  if ( obj === void 0 ) obj = {};
  if ( requireds === void 0 ) requireds = [];

  return Object.entries(obj).reduce(function (acc, ref) {
  var key = ref[0];

  var required = requireds.includes(key);
  if (required) { acc[key] = false; }
  return acc;
}, {});
}; // https://repl.it/@viniazvd/objFilter


var objFilter = function (data, keys) {
  if ( data === void 0 ) data = {};
  if ( keys === void 0 ) keys = [];

  return JSON.parse(JSON.stringify(data, keys));
}; // https://repl.it/@viniazvd/findBy


var findBy = function (list, strings, keys, terms) {
  if ( list === void 0 ) list = [];
  if ( strings === void 0 ) strings = '';
  if ( keys === void 0 ) keys = [];
  if ( terms === void 0 ) terms = strings.toLowerCase().split(' ');

  return list.filter(function (el) { return terms.some(function (v) { return keys.some(function (k) { return el[k].toLowerCase().includes(v); }); }); });
}; // https://repl.it/@viniazvd/regexValidation


var regexValidation = function (type, value) {
  var fields = {
    email: /^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9-]+(?:\.[a-zA-Z0-9-]+)*$/,
    phone: /^\([1-9]{2}\) [2-9][0-9]{3,4}\-[0-9]{4}$/,
    birthday: /^[0-9]{4}[\-][0-9]{2}[\-][0-9]{2}$/,
    gender: /^(masculino|feminino|outro)$/
  };
  return fields[type].test(value);
}; // https://repl.it/@viniazvd/intersect


var intersect = function (array1, array2, param) {
  var setObj = new Set(array1.map(function (array1) { return array1[param]; }));
  return array2.filter(function (array2) { return !setObj.has(array2[param]); });
};

var functions = {
  isValid: isValid,
  getAbsolutValue: getAbsolutValue,
  isMobile: isMobile,
  clone: clone,
  containsWord: containsWord,
  removeDuplicates: removeDuplicates,
  pagination: pagination,
  equals: equals,
  translateEntity: translateEntity,
  isFormValid: isFormValid,
  formValidator: formValidator,
  formRequireds: formRequireds,
  objFilter: objFilter,
  findBy: findBy,
  regexValidation: regexValidation,
  intersect: intersect
};
var index = (function (Vue) {
  Object.defineProperty(Vue.prototype, '$utils', {
    get: function get() {
      return functions;
    }

  });
});

module.exports = index;
